$.jqplot.CanvasAxisLabelRenderer

Renderer to draw axis labels with a canvas element to support advanced featrues such as rotated text. This renderer uses a separate rendering engine to draw the text on the canvas. Two modes of rendering the text are available. If the browser has native font support for canvas fonts (currently Mozila 3.5 and Safari 4), you can enable text rendering with the canvas fillText method. You do so by setting the “enableFontSupport” option to true.

Browsers lacking native font support will have the text drawn on the canvas using the Hershey font metrics. Even if the “enableFontSupport” option is true non-supporting browsers will still render with the Hershey font.

Summary

$.jqplot.CanvasAxisLabelRenderer | Renderer to draw axis labels with a canvas element to support advanced featrues such as rotated text.
Properties |
angle | angle of text, measured clockwise from x axis.
show | whether or not to show the tick (mark and label).
showLabel | whether or not to show the label.
label | label for the axis.
fontFamily | CSS spec for the font-family css attribute.
fontSize | CSS spec for font size.
fontWeight |
fontStretch | Multiplier to condense or expand font width.
textColor | css spec for the color attribute.
enableFontSupport | true to turn on native canvas font support in Mozilla 3.5+ and Safari 4+.
pt2px | Point to pixel scaling factor, used for computing height of bounding box around a label.

### Properties

### angle

> this.angle = 0

angle of text, measured clockwise from x axis.

### show

> this.show = true

whether or not to show the tick (mark and label).

### showLabel

> this.showLabel = true

whether or not to show the label.

### label

> this.label = ''

label for the axis.

### fontFamily

> this.fontFamily = '"Trebuchet MS", Arial, Helvetica, sans-serif'

CSS spec for the font-family css attribute. Applies only to browsers supporting native font rendering in the canvas tag. Currently Mozilla 3.5 and Safari 4.

### fontSize

> this.fontSize = '11pt'

CSS spec for font size.

### fontWeight

> this.fontWeight = 'normal'

CSS spec for fontWeight: normal, bold, bolder, lighter or a number 100 | 900

### fontStretch

> this.fontStretch = 1.0

Multiplier to condense or expand font width. Applies only to browsers which don’t support canvas native font rendering.

### textColor

> this.textColor = '#666666'

css spec for the color attribute.

### enableFontSupport

> this.enableFontSupport = true

true to turn on native canvas font support in Mozilla 3.5+ and Safari 4+. If true, label will be drawn with canvas tag native support for fonts. If false, label will be drawn with Hershey font metrics.

### pt2px

> this.pt2px = null

Point to pixel scaling factor, used for computing height of bounding box around a label. The labels text renderer has a default setting of 1.4, which should be suitable for most fonts. Leave as null to use default. If tops of letters appear clipped, increase this. If bounding box seems too big, decrease. This is an issue only with the native font renderering capabilities of Mozilla 3.5 and Safari 4 since they do not provide a method to determine the font height.

> this.angle = 0

angle of text, measured clockwise from x axis.

> this.show = true

whether or not to show the tick (mark and label).

> this.showLabel = true

whether or not to show the label.

> this.label = ''

label for the axis.

> this.fontFamily = '"Trebuchet MS", Arial, Helvetica, sans-serif'

CSS spec for the font-family css attribute.

> this.fontSize = '11pt'

CSS spec for font size.

> this.fontWeight = 'normal'

> this.fontStretch = 1.0

Multiplier to condense or expand font width.

> this.textColor = '#666666'

css spec for the color attribute.

> this.enableFontSupport = true

true to turn on native canvas font support in Mozilla 3.5+ and Safari 4+.

> this.pt2px = null

Point to pixel scaling factor, used for computing height of bounding box around a label.
Close